==> jc-1.4.0.tar.gz: polyglot/visit/StringPrettyPrinter.h <==
// public class polyglot.visit.StringPrettyPrinter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9b5998bb4b90b099 polyglot_visit_PrettyPrinter
// @dep_class 26376dc7c5d12066 polyglot_visit_StringPrettyPrinter

// header file dependencies
// @dep_header polyglot_visit_PrettyPrinter

#include "polyglot/visit/PrettyPrinter.h"

#ifndef _JC_polyglot_visit_StringPrettyPrinter_H_
#define _JC_polyglot_visit_StringPrettyPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;

// Typedefs
typedef struct _jc_polyglot_visit_StringPrettyPrinter$sub_refs	_jc_polyglot_visit_StringPrettyPrinter$sub_refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs	_jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$refs	_jc_polyglot_visit_StringPrettyPrinter$refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$nonrefs	_jc_polyglot_visit_StringPrettyPrinter$nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$object	_jc_polyglot_visit_StringPrettyPrinter$object;

typedef const struct _jc_polyglot_visit_StringPrettyPrinter$vmethods	_jc_polyglot_visit_StringPrettyPrinter$vmethods;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter$vtable	_jc_polyglot_visit_StringPrettyPrinter$vtable;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter$vtype	_jc_polyglot_visit_StringPrettyPrinter$vtype;

// Constructors
extern void _jc_polyglot_visit_StringPrettyPrinter$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, jint);

// Virtual methods
extern void _jc_polyglot_visit_StringPrettyPrinter$method$print$be8fd119cbff90e9(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_StringPrettyPrinter$method$toString$876c5a3991f62bf7(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter$method_info$print$be8fd119cbff90e9;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter$method_info$toString$876c5a3991f62bf7;

// Virtual methods structure
struct _jc_polyglot_visit_StringPrettyPrinter$vmethods {
	void	(*print$be8fd119cbff90e9)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *);
	struct _jc_java_lang_String$object	*(*toString$876c5a3991f62bf7)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_visit_StringPrettyPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_PrettyPrinter$vmethods	polyglot_visit_PrettyPrinter;
	_jc_polyglot_visit_StringPrettyPrinter$vmethods	polyglot_visit_StringPrettyPrinter;
};

// Vtype
struct _jc_polyglot_visit_StringPrettyPrinter$vtype {
	_jc_type			type;
	_jc_polyglot_visit_StringPrettyPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter$refs {
    _jc_polyglot_visit_StringPrettyPrinter$sub_refs	polyglot_visit_StringPrettyPrinter;
    _jc_polyglot_visit_PrettyPrinter$sub_refs	polyglot_visit_PrettyPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs {
	jint	maxdepth;
	jint	depth;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_PrettyPrinter$sub_nonrefs	polyglot_visit_PrettyPrinter;
    _jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs	polyglot_visit_StringPrettyPrinter;
};

// Object instance structure
struct _jc_polyglot_visit_StringPrettyPrinter$object {
	_jc_polyglot_visit_StringPrettyPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_StringPrettyPrinter$vtype	*vtype;
	_jc_polyglot_visit_StringPrettyPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_StringPrettyPrinter$vtype _jc_polyglot_visit_StringPrettyPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_StringPrettyPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_StringPrettyPrinter$class_object;

#endif	/* _JC_polyglot_visit_StringPrettyPrinter_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/StringPrettyPrinter.h <==
// public class polyglot.visit.StringPrettyPrinter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9b5998bb4b90b099 polyglot_visit_PrettyPrinter
// @dep_class 26376dc7c5d12066 polyglot_visit_StringPrettyPrinter

// header file dependencies
// @dep_header polyglot_visit_PrettyPrinter

#include "polyglot/visit/PrettyPrinter.h"

#ifndef _JC_polyglot_visit_StringPrettyPrinter_H_
#define _JC_polyglot_visit_StringPrettyPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;

// Typedefs
typedef struct _jc_polyglot_visit_StringPrettyPrinter$sub_refs	_jc_polyglot_visit_StringPrettyPrinter$sub_refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs	_jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$refs	_jc_polyglot_visit_StringPrettyPrinter$refs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$nonrefs	_jc_polyglot_visit_StringPrettyPrinter$nonrefs;
typedef struct _jc_polyglot_visit_StringPrettyPrinter$object	_jc_polyglot_visit_StringPrettyPrinter$object;

typedef const struct _jc_polyglot_visit_StringPrettyPrinter$vmethods	_jc_polyglot_visit_StringPrettyPrinter$vmethods;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter$vtable	_jc_polyglot_visit_StringPrettyPrinter$vtable;
typedef const struct _jc_polyglot_visit_StringPrettyPrinter$vtype	_jc_polyglot_visit_StringPrettyPrinter$vtype;

// Constructors
extern void _jc_polyglot_visit_StringPrettyPrinter$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_visit_StringPrettyPrinter$method$print$be8fd119cbff90e9(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_StringPrettyPrinter$method$toString$876c5a3991f62bf7(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter$method_info$print$be8fd119cbff90e9;
extern _jc_method _jc_polyglot_visit_StringPrettyPrinter$method_info$toString$876c5a3991f62bf7;

// Virtual methods structure
struct _jc_polyglot_visit_StringPrettyPrinter$vmethods {
	void	(*print$be8fd119cbff90e9)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$876c5a3991f62bf7)(_jc_env *, struct _jc_polyglot_visit_StringPrettyPrinter$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_StringPrettyPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_PrettyPrinter$vmethods	polyglot_visit_PrettyPrinter;
	_jc_polyglot_visit_StringPrettyPrinter$vmethods	polyglot_visit_StringPrettyPrinter;
};

// Vtype
struct _jc_polyglot_visit_StringPrettyPrinter$vtype {
	_jc_type			type;
	_jc_polyglot_visit_StringPrettyPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter$refs {
    _jc_polyglot_visit_StringPrettyPrinter$sub_refs	polyglot_visit_StringPrettyPrinter;
    _jc_polyglot_visit_PrettyPrinter$sub_refs	polyglot_visit_PrettyPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs {
	jint	maxdepth;
	jint	depth;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_StringPrettyPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_PrettyPrinter$sub_nonrefs	polyglot_visit_PrettyPrinter;
    _jc_polyglot_visit_StringPrettyPrinter$sub_nonrefs	polyglot_visit_StringPrettyPrinter;
};

// Object instance structure
struct _jc_polyglot_visit_StringPrettyPrinter$object {
	_jc_polyglot_visit_StringPrettyPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_StringPrettyPrinter$vtype	*vtype;
	_jc_polyglot_visit_StringPrettyPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_StringPrettyPrinter$vtype _jc_polyglot_visit_StringPrettyPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_StringPrettyPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_StringPrettyPrinter$class_object;

#endif	/* _JC_polyglot_visit_StringPrettyPrinter_H_ */
